==> geant4.9.6.p03.tar.gz: geant4.9.6.p03/source/processes/electromagnetic/dna/utils/src/G4DNADamages.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4DNADamages.cc 65022 2012-11-12 16:43:12Z gcosmo $
//
#include "G4DNADamages.hh"
#include "G4UnitsTable.hh"

G4DNADamages* G4DNADamages::fpInstance(0);

G4DNAIndirectHit::G4DNAIndirectHit(const G4String& baseName,
                                   const G4Molecule* molecule,
                                   const G4ThreeVector& position,
                                   G4double time) : G4VDNAHit(),
    fpMolecule(molecule)
{
    fBaseName = baseName;
    fPosition = position;
    fTime = time;
}


G4DNAIndirectHit::~G4DNAIndirectHit()
{
    if(fpMolecule) delete fpMolecule;
    fpMolecule = 0;
}

void G4DNAIndirectHit::Print()
{
    G4cout << "Reaction : " << fpMolecule->GetName() << " + " << fBaseName
           << " at position : " << G4BestUnit(fPosition,"Length")
           << " and time : " << G4BestUnit(fTime,"Time") << G4endl;
}


G4DNADamages* G4DNADamages::Instance()
{
    if(!fpInstance) new G4DNADamages();

    return fpInstance;
}

G4DNADamages::G4DNADamages()
{
    fJustCountDamage = false;
    fNIndirectDamages = 0;
    fpInstance = this;
}

G4DNADamages::~G4DNADamages()
{
    for(int i = 0 ; i <(int) fIndirectHits.size() ; i++)
    {
        if(fIndirectHits[i])
            delete fIndirectHits[i];
    }
    fIndirectHits.clear();
}

void G4DNADamages::DeleteInstance()
{
    if(fpInstance) delete fpInstance;
    fpInstance = 0;
}

void G4DNADamages::Reset()
{
    fNIndirectDamages = 0;
    for(int i = 0 ; i <(int) fIndirectHits.size() ; i++)
    {
        if(fIndirectHits[i])
            delete fIndirectHits[i];
    }
    fIndirectHits.clear();
}

void G4DNADamages::AddIndirectDamage(const G4String& baseName,
                                     const G4Molecule* molecule,
                                     const G4ThreeVector& position,
                                     G4double time)
{
    if(fJustCountDamage)
    {
        fNIndirectDamages++;
        return;
    }

    G4DNAIndirectHit* indirectHit  = 0;
    std::map<G4Molecule, const G4Molecule*>::iterator it = fMolMap.find(*molecule);

    if(it == fMolMap.end())
    {
        G4Molecule* mol(0);
        fMolMap[*molecule] = (mol = new G4Molecule(*molecule));
        indirectHit = new G4DNAIndirectHit(baseName, mol, position, time);
    }
    else
    {
        indirectHit = new G4DNAIndirectHit(baseName, it->second, position, time);
    }
    fIndirectHits.push_back(indirectHit);
}

==> geant4.10.00.tar.gz: geant4.10.00/source/processes/electromagnetic/dna/utils/src/G4DNADamages.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4DNADamages.cc 66872 2013-01-15 01:25:57Z japost $
//
#include "G4DNADamages.hh"
#include "G4UnitsTable.hh"

G4ThreadLocal G4DNADamages* G4DNADamages::fpInstance(0);

G4DNAIndirectHit::G4DNAIndirectHit(const G4String& baseName,
                                   const G4Molecule* molecule,
                                   const G4ThreeVector& position,
                                   G4double time) : G4VDNAHit(),
    fpMolecule(molecule)
{
    fBaseName = baseName;
    fPosition = position;
    fTime = time;
}


G4DNAIndirectHit::~G4DNAIndirectHit()
{
    if(fpMolecule) delete fpMolecule;
    fpMolecule = 0;
}

void G4DNAIndirectHit::Print()
{
    G4cout << "Reaction : " << fpMolecule->GetName() << " + " << fBaseName
           << " at position : " << G4BestUnit(fPosition,"Length")
           << " and time : " << G4BestUnit(fTime,"Time") << G4endl;
}


G4DNADamages* G4DNADamages::Instance()
{
    if(!fpInstance) new G4DNADamages();

    return fpInstance;
}

G4DNADamages::G4DNADamages()
{
    fJustCountDamage = false;
    fNIndirectDamages = 0;
    fpInstance = this;
}

G4DNADamages::~G4DNADamages()
{
    for(int i = 0 ; i <(int) fIndirectHits.size() ; i++)
    {
        if(fIndirectHits[i])
            delete fIndirectHits[i];
    }
    fIndirectHits.clear();
}

void G4DNADamages::DeleteInstance()
{
    if(fpInstance) delete fpInstance;
    fpInstance = 0;
}

void G4DNADamages::Reset()
{
    fNIndirectDamages = 0;
    for(int i = 0 ; i <(int) fIndirectHits.size() ; i++)
    {
        if(fIndirectHits[i])
            delete fIndirectHits[i];
    }
    fIndirectHits.clear();
}

void G4DNADamages::AddIndirectDamage(const G4String& baseName,
                                     const G4Molecule* molecule,
                                     const G4ThreeVector& position,
                                     G4double time)
{
    if(fJustCountDamage)
    {
        fNIndirectDamages++;
        return;
    }

    G4DNAIndirectHit* indirectHit  = 0;
    std::map<G4Molecule, const G4Molecule*>::iterator it = fMolMap.find(*molecule);

    if(it == fMolMap.end())
    {
        G4Molecule* mol(0);
        fMolMap[*molecule] = (mol = new G4Molecule(*molecule));
        indirectHit = new G4DNAIndirectHit(baseName, mol, position, time);
    }
    else
    {
        indirectHit = new G4DNAIndirectHit(baseName, it->second, position, time);
    }
    fIndirectHits.push_back(indirectHit);
}
